@@ -6,7 +6,7 @@ import config
 
 
 def serve():
-    app.run(debug=False, port=config.port, host="")
+    app.run(debug=True, use_reloader=False, port=config.port, host="")
 
 
 def play():
